library(igraph)

#import graph
g <- read.graph("Recon2_compound-graph.gml", format="gml")

#optional : turn into undirected graph
g <- as.undirected(g)

#import attributs
status <- read.csv("recon_mapping_status.csv", header = TRUE, sep = "\t", row.names = 1)

#change logical values to numeric
status.matrix <- as.matrix(status)
status.matrix <- status.matrix*1

vertex_attr(g, "mapped", V(g)) <-  status.matrix[,1]

#plot of the largest community
gclust = clusters(g)
numClust = gclust$no # number of connected component
numLCC = gclust$csize[1] # number of nodes in LCC
lcc = gclust$membership[1]
lcc = induced.subgraph(g, V(g)[which(gclust$membership == which.max(gclust$csize))])

plot(lcc, vertex.label=NA, vertex.color=V(g)$mapped,vertex.size=2, layout=layout.fruchterman.reingold)

# repeted community detection using label propagation
communities=cluster_label_prop(g, weights = NA, initial = vertex_attr(g,"mapped"))
res<-as.matrix(membership(communities))
for(i in 2:1000){
	communities=cluster_label_prop(g, weights = NA, initial = vertex_attr(g,"mapped"))
	res<-cbind(res,as.matrix(membership(communities)))
}

# get final assignement
poorly_mapped_membership <- apply(res,1,function(x) sum(x==2)>=500)
vertex_attr(g, "coveragestatus", V(g)) <- poorly_mapped_membership
vertex_attr(g, "numberOfClassifAsPoorly", V(g)) <- rowSums(res==2)
vertex_attr(g, "degree", V(g)) <- degree(g)

#get induced subgraphs
poorly_mapped <-induced.subgraph(g,poorly_mapped_membership)
not_mapped <- induced.subgraph(g,V(g)$mapped==0)

#plots
par(mfrow=c(1,2))
l<-layout.fruchterman.reingold(not_mapped)
l0<-layout.fruchterman.reingold(poorly_mapped)

plot(poorly_mapped, vertex.label=NA, layout=l0, vertex.color=V(poorly_mapped)$mapped, layout=layout.fruchterman.reingold, vertex.size=2)
plot(g, vertex.label=NA, vertex.color=poorly_mapped_membership,vertex.size=2)

plot(poorly_mapped, vertex.label=NA, layout=l0, vertex.color=V(poorly_mapped)$mapped,vertex.size=2)
plot(not_mapped, vertex.label=NA, layout=l, vertex.color=V(not_mapped)$mapped,vertex.size=2)

plot(not_mapped, vertex.label=NA, layout=l, vertex.color=color.scale(V(not_mapped)$numberOfClassifAsPoorly,1,c(1,0),c(1,0)),vertex.size=((degree(not_mapped)+1)/(V(not_mapped)$degree+1))*4)
plot(not_mapped, vertex.label=NA, layout=l, vertex.color=V(not_mapped)$coveragestatus,vertex.size=((degree(not_mapped)+1)/(V(not_mapped)$degree+1))*4)
